﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using igDataChartMVCExporttoPDF.Models;
using Infragistics.Documents.Reports;
using Infragistics.Documents.Reports.Report;
using Infragistics.Documents.Reports.Report.Section;
using Infragistics.Documents.Reports.Report.Text;
using Infragistics.Documents.Reports.Graphics;
using System.IO;
using System.Drawing;



namespace igDataChartMVCExporttoPDF.Controllers
{
    public class HomeController : Controller
    {
        //
        // GET: /Home/

        public ActionResult Index()
        {
            //This object will serve as the basis for binding to data
            //on the Index.cshtml View with the MVC Helpers. See:
            //@model = OctaneUIWebApplication5.Models.CustomersViewModel
            var viewModel = new CustomersViewModel
            {
                //IEnumerable of Customer Objects
                Customers = GetCustomers(),

                //IEnumerable of CustomerCountSummary Objects
                //For use with binding to the Chart
                CustomerCountSummaries = GetCustomerCounts()
            };

            return View(viewModel);
        }

        //This method aggregates the Customer data into a format that is easily
        //consumed by the Chart
        private IEnumerable<CustomerCountSummary> GetCustomerCounts()
        {
            var customers = GetCustomers();
            var active = from c in customers
                         where c.IsActive
                         select c;

            var inActive = from c in customers
                           where (c.IsActive == false)
                           select c;

            return new List<CustomerCountSummary> { 
                new CustomerCountSummary { CategoryLabel = "Active", CustomerCount = active.Count() },
                new CustomerCountSummary { CategoryLabel = "Inactive", CustomerCount = inActive.Count() }
            };
        }

        private IEnumerable<Customer> GetCustomers()
        {
            return new List<Customer>
            {
                new Customer { ID=1, Name="John Smith", IsActive=true },
                new Customer { ID=2, Name="Bob Richards", IsActive=false },
                new Customer { ID=3, Name="Marge Wright", IsActive=false },
                new Customer { ID=4, Name="Dwight Long", IsActive=true },
                new Customer { ID=5, Name="Amy Grant", IsActive=true },
            };
        }

        // ********************* Exporting to PDF ******************************************* //
        
        [ActionName("CreatePDF")]
        public void CreatePDF(string img)
        {
            Report report = GenerateDoc(img);

            //send for download
            Response.Clear();
            Response.ContentType = "application/octet-stream";
            Response.AppendHeader("content-disposition", "attachement; filename=" + "Document.pdf");
            report.Publish(Response.OutputStream, FileFormat.PDF);
            Response.End();
        }

        // PDF report
        #region Report
        private Report GenerateDoc(string img)
        {
            //create new Report instance
            Report report = new Report();

            //Adding a section to the Report
            ISection section = report.AddSection();

            //set the page orientation
            section.PageOrientation = PageOrientation.Portrait;
            //add nice margins to all sides
            section.PageMargins.All = 20;

            //add paging
            section.PageNumbering.Template = "Page [Page #] of [TotalPages]";
            //bring it up abit to be above the margin
            section.PageNumbering.OffsetY = -22;

            //add footer
            ISectionFooter sectionFooter = section.AddFooter();
            sectionFooter.Repeat = true;
            sectionFooter.Height = 50;
            //add text to the footer
            IText sectionFooterText = sectionFooter.AddText(0, 0);
            sectionFooterText.Paddings.All = 10;
            sectionFooterText.Alignment = new TextAlignment(Alignment.Center, Alignment.Middle);
            sectionFooterText.Height = new RelativeHeight(100);
            sectionFooterText.Background = new Background(Infragistics.Documents.Reports.Graphics.Brushes.Gainsboro);
            sectionFooterText.AddContent("PDF report created by Infragistics Documents.");

            //Add Title
            var title = section.AddQuickText("igDataChart Report");
            title.Font = new Infragistics.Documents.Reports.Graphics.Font("Verdana", 24);
            section.AddRule();
            //Adding Text to the Section
            IText text = section.AddText();

            string paragraph = "Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Donec imperdiet mattis sem. Nunc ornare elit at justo. In quam nulla, lobortis non, commodo eu, eleifend in, elit. Nulla eleifend. Nulla convallis. Sed eleifend auctor purus. Donec velit diam, congue quis, eleifend et, pretium id, tortor. Nulla semper condimentum justo. Etiam interdum odio ut ligula. Vivamus egestas scelerisque est. Donec accumsan. In est urna, vehicula non, nonummy sed, malesuada nec, purus. Vestibulum erat. Vivamus lacus enim, rhoncus nec, ornare sed, scelerisque varius, felis. Nam eu libero vel massa lobortis accumsan. Vivamus id orci. Sed sed lacus sit amet nibh pretium sollicitudin. Morbi urna.";
            text.AddContent(paragraph);
            section.AddRule();

            //Add the container element
            IContainer container = section.AddContainer("Container");

            //**** Add main content here ****
            container.AddQuickText("\n");
            container.AddQuickText("\n");
            container.AddQuickText("igDataChart below:");
            var imgBinData = Convert.FromBase64String(img);
            System.Drawing.Image newIMG = new Bitmap(new MemoryStream(imgBinData));
            container.AddQuickImage(new Infragistics.Documents.Reports.Graphics.Image(newIMG));

            //container.AddQuickImage.;
            //settings:
            report.Info.Author = "You";
            report.Info.Creator = "Infragistics Document Engine";
            report.Preferences.Printing.PaperSize = Infragistics.Documents.Reports.Report.Preferences.Printing.PaperSize.A4;

            return report;
        }
        #endregion

        public System.Drawing.Image byteArrayToImage(byte[] img)
        {
            MemoryStream ms = new MemoryStream(img);
            System.Drawing.Image returnImage = System.Drawing.Image.FromStream(ms);
            return returnImage;
        }
    }
}
